=== modified file 'NEWS'
--- NEWS	2008-12-12 03:53:56 +0000
+++ NEWS	2008-12-12 12:14:01 +0000
@@ -54,6 +54,9 @@
     * ``pull -v`` now respects the log_format configuration variable.
       (Aaron Bentley)
 
+    * Use the short status format when the short format is used for log.
+      (Vincent Ladeuil, #87179)
+
   DOCUMENTATION:
 
   API CHANGES:

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2008-12-11 06:03:57 +0000
+++ bzrlib/builtins.py	2008-12-12 12:14:01 +0000
@@ -56,7 +56,7 @@
 
 from bzrlib.commands import Command, display_command
 from bzrlib.option import ListOption, Option, RegistryOption, custom_help
-from bzrlib.trace import mutter, note, warning, is_quiet
+from bzrlib.trace import mutter, note, warning, is_quiet, get_verbosity_level
 
 
 def tree_files(file_list, default_branch=u'.'):
@@ -1871,7 +1871,8 @@
                 log_format = log.log_formatter_registry.get_default(b)
 
             lf = log_format(show_ids=show_ids, to_file=self.outf,
-                            show_timezone=timezone)
+                            show_timezone=timezone,
+                            delta_format=get_verbosity_level())
 
             show_log(b,
                      lf,

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2008-09-15 03:23:53 +0000
+++ bzrlib/delta.py	2008-12-01 16:51:55 +0000
@@ -104,7 +104,7 @@
             if v[1] == file_id:
                 return True
         return False
-            
+
 
     def show(self, to_file, show_ids=False, show_unchanged=False,
              short_status=False, indent=''):
@@ -126,14 +126,14 @@
                         path, fid))
                 else:
                     to_file.write(indent + '%s  %s\n' % (short_status_letter, path))
-            
+
         if self.removed:
             if not short_status:
                 to_file.write(indent + 'removed:\n')
                 show_list(self.removed)
             else:
                 show_list(self.removed, 'D')
-                
+
         if self.added:
             if not short_status:
                 to_file.write(indent + 'added:\n')

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2008-11-27 03:18:40 +0000
+++ bzrlib/log.py	2008-12-11 07:12:28 +0000
@@ -147,31 +147,25 @@
              limit=None):
     """Write out human-readable log of commits to this branch.
 
-    lf
-        LogFormatter object to show the output.
-
-    specific_fileid
-        If true, list only the commits affecting the specified
-        file, rather than all commits.
-
-    verbose
-        If true show added/changed/deleted/renamed files.
-
-    direction
-        'reverse' (default) is latest to earliest;
-        'forward' is earliest to latest.
-
-    start_revision
-        If not None, only show revisions >= start_revision
-
-    end_revision
-        If not None, only show revisions <= end_revision
-
-    search
-        If not None, only show revisions with matching commit messages
-
-    limit
-        If not None or 0, only show limit revisions
+    :param lf: The LogFormatter object showing the output.
+
+    :param specific_fileid: If not None, list only the commits affecting the
+        specified file, rather than all commits.
+
+    :param verbose: If True show added/changed/deleted/renamed files.
+
+    :param direction: 'reverse' (default) is latest to earliest; 'forward' is
+        earliest to latest.
+
+    :param start_revision: If not None, only show revisions >= start_revision
+
+    :param end_revision: If not None, only show revisions <= end_revision
+
+    :param search: If not None, only show revisions with matching commit
+        messages
+
+    :param limit: If set, shows only 'limit' revisions, all revisions are shown
+        if None or 0.
     """
     branch.lock_read()
     try:
@@ -398,7 +392,8 @@
     :param search: A user text search string.
     :param log_rev_iterator: An input iterator containing all revisions that
         could be displayed, in lists.
-    :return: An iterator over lists of ((rev_id, revno, merge_depth), rev, delta).
+    :return: An iterator over lists of ((rev_id, revno, merge_depth), rev,
+        delta).
     """
     repository = branch.repository
     num = 9
@@ -649,7 +644,8 @@
     elif direction != 'reverse':
         raise ValueError('invalid direction %r' % direction)
 
-    for sequence, rev_id, merge_depth, revno, end_of_merge in merge_sorted_revisions:
+    for (sequence, rev_id, merge_depth, revno, end_of_merge
+         ) in merge_sorted_revisions:
         yield rev_id, '.'.join(map(str, revno)), merge_depth
 
 
@@ -713,7 +709,10 @@
     to indicate which LogRevision attributes it supports:
 
     - supports_delta must be True if this log formatter supports delta.
-        Otherwise the delta attribute may not be populated.
+        Otherwise the delta attribute may not be populated.  The 'delta_format'
+        attribute describes whether the 'short_status' format (1) or the long
+        one (2) sould be used.
+ 
     - supports_merge_revisions must be True if this log formatter supports 
         merge revisions.  If not, and if supports_single_merge_revisions is
         also not True, then only mainline revisions will be passed to the 
@@ -732,10 +731,15 @@
             # to be shown
     """
 
-    def __init__(self, to_file, show_ids=False, show_timezone='original'):
+    def __init__(self, to_file, show_ids=False, show_timezone='original',
+                 delta_format=None):
         self.to_file = to_file
         self.show_ids = show_ids
         self.show_timezone = show_timezone
+        if delta_format is None:
+            # Ensures backward compatibility
+            delta_format = 2 # long format
+        self.delta_format = delta_format
 
 # TODO: uncomment this block after show() has been removed.
 # Until then defining log_revision would prevent _show_log calling show() 
@@ -813,7 +817,9 @@
             for l in message.split('\n'):
                 to_file.write(indent + '  %s\n' % (l,))
         if revision.delta is not None:
-            revision.delta.show(to_file, self.show_ids, indent=indent)
+            # We don't respect delta_format for compatibility
+            revision.delta.show(to_file, self.show_ids, indent=indent,
+                                short_status=False)
 
 
 class ShortLogFormatter(LogFormatter):
@@ -834,7 +840,8 @@
                             show_offset=False),
                 is_merge))
         if self.show_ids:
-            to_file.write('      revision-id:%s\n' % (revision.rev.revision_id,))
+            to_file.write('      revision-id:%s\n'
+                          % (revision.rev.revision_id,))
         if not revision.rev.message:
             to_file.write('      (no message)\n')
         else:
@@ -842,10 +849,9 @@
             for l in message.split('\n'):
                 to_file.write('      %s\n' % (l,))
 
-        # TODO: Why not show the modified files in a shorter form as
-        # well? rewrap them single lines of appropriate length
         if revision.delta is not None:
-            revision.delta.show(to_file, self.show_ids)
+            revision.delta.show(to_file, self.show_ids,
+                                short_status=self.delta_format==1)
         to_file.write('\n')
 
 

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2008-12-04 19:59:34 +0000
+++ bzrlib/tests/blackbox/test_log.py	2008-12-12 12:14:01 +0000
@@ -244,6 +244,44 @@
         self.assertContainsRe(log, r'revno: 3\n')
 
 
+class TestLogVerbose(TestCaseWithTransport):
+
+    def setUp(self):
+        super(TestLogVerbose, self).setUp()
+        tree = self.make_branch_and_tree('.')
+        self.build_tree(['hello.txt'])
+        tree.add('hello.txt')
+        tree.commit(message='message1')
+
+    def assertUseShortDeltaFormat(self, cmd):
+        log = self.run_bzr(cmd)[0]
+        # Check that we use the short status format
+        self.assertContainsRe(log, '(?m)^A  hello.txt$')
+        self.assertNotContainsRe(log, '(?m)^added:$')
+
+    def assertUseLongDeltaFormat(self, cmd):
+        log = self.run_bzr(cmd)[0]
+        # Check that we use the long status format
+        self.assertNotContainsRe(log, '(?m)^A  hello.txt$')
+        self.assertContainsRe(log, '(?m)^added:$')
+
+    def test_log_short_verbose(self):
+        self.assertUseShortDeltaFormat(['log', '--short', '-v'])
+
+    def test_log_short_verbose_verbose(self):
+        self.assertUseLongDeltaFormat(['log', '--short', '-vv'])
+
+    def test_log_long_verbose(self):
+        # Check that we use the long status format, ignoring the verbosity
+        # level
+        self.assertUseLongDeltaFormat(['log', '--long', '-v'])
+
+    def test_log_long_verbose_verbose(self):
+        # Check that we use the long status format, ignoring the verbosity
+        # level
+        self.assertUseLongDeltaFormat(['log', '--long', '-vv'])
+
+
 class TestLogMerges(TestCaseWithoutPropsHandler):
 
     def _prepare(self):

